@@ -1,7 +1,7 @@
 package MooseX::NonMoose::InsideOut;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
+
 
-use Moose ();
 use Moose::Exporter;
 
 =head1 NAME
@@ -10,11 +10,14 @@ MooseX::NonMoose::InsideOut - easy subclassing of non-Moose non-hashref classes
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
   package Term::VT102::NBased;
+our $VERSION = '0.06';
+
+
   use Moose;
   use MooseX::NonMoose::InsideOut;
   extends 'Term::VT102';
@@ -43,21 +46,19 @@ version 0.05
 
 =cut
 
-Moose::Exporter->setup_import_methods;
+my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
+    metaclass_roles          => ['MooseX::NonMoose::Meta::Role::Class'],
+    constructor_class_roles  => ['MooseX::NonMoose::Meta::Role::Constructor'],
+    instance_metaclass_roles => ['MooseX::InsideOut::Role::Meta::Instance'],
+    install                  => [qw(import unimport)],
+);
 
 sub init_meta {
-    shift;
+    my $package = shift;
     my %options = @_;
-    Moose->init_meta(%options);
-    Moose::Util::MetaRole::apply_metaclass_roles(
-        for_class               => $options{for_class},
-        metaclass_roles         => ['MooseX::NonMoose::Meta::Role::Class'],
-        constructor_class_roles =>
-            ['MooseX::NonMoose::Meta::Role::Constructor'],
-        instance_metaclass_roles =>
-            ['MooseX::InsideOut::Role::Meta::Instance'],
-    );
-    return Class::MOP::class_of($options{for_class});
+    Carp::cluck('Roles have no use for MooseX::NonMoose')
+        if Class::MOP::class_of($options{for_class})->isa('Moose::Meta::Role');
+    $package->$init_meta(@_);
 }
 
 =head1 AUTHOR
